"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.CmsFilesStorage = void 0;
var _omit = _interopRequireDefault(require("lodash/omit"));
var _ListFilesWhereProcessor = require("./ListFilesWhereProcessor");
var _ListTagsWhereProcessor = require("./ListTagsWhereProcessor");
var _contants = require("../contants");
class CmsFilesStorage {
  static async create(params) {
    return new CmsFilesStorage(params.fileModel, params.cms, params.security, params.aliases);
  }
  constructor(fileModel, cms, security, aliases) {
    this.model = fileModel;
    this.aliases = aliases;
    this.cms = cms;
    this.security = security;
    this.filesWhereProcessor = new _ListFilesWhereProcessor.ListFilesWhereProcessor();
    this.tagsWhereProcessor = new _ListTagsWhereProcessor.ListTagsWhereProcessor();
  }
  modelWithContext({
    tenant,
    locale
  }) {
    return {
      ...this.model,
      tenant,
      locale
    };
  }
  async create({
    file
  }) {
    const model = this.modelWithContext(file);
    if (!file.location?.folderId) {
      file.location = {
        ...file.location,
        folderId: _contants.ROOT_FOLDER
      };
    }
    const entry = await this.security.withoutAuthorization(() => {
      return this.cms.createEntry(model, {
        ...file,
        wbyAco_location: file.location
      });
    });
    await this.aliases.storeAliases(file);
    return this.getFileFieldValues(entry);
  }
  async createBatch({
    files
  }) {
    return await Promise.all(files.map(file => {
      return this.create({
        file
      });
    }));
  }
  async delete({
    file
  }) {
    const model = this.modelWithContext(file);
    await this.security.withoutAuthorization(() => {
      return this.cms.deleteEntry(model, file.id);
    });
    await this.aliases.deleteAliases(file);
  }
  async get({
    where
  }) {
    const {
      id,
      tenant,
      locale
    } = where;
    const model = this.modelWithContext({
      tenant,
      locale
    });
    const entry = await this.security.withoutAuthorization(() => {
      return this.cms.getEntry(model, {
        where: {
          entryId: id,
          latest: true
        }
      });
    });
    return entry ? this.getFileFieldValues(entry) : null;
  }
  async list(params) {
    const tenant = params.where.tenant;
    const locale = params.where.locale;
    const model = this.modelWithContext({
      tenant,
      locale
    });
    const [entries, meta] = await this.security.withoutAuthorization(() => {
      const where = this.filesWhereProcessor.process(params.where);
      return this.cms.listLatestEntries(model, {
        after: params.after,
        limit: params.limit,
        sort: params.sort,
        where,
        search: params.search
      });
    });
    return [entries.map(entry => this.getFileFieldValues(entry)), meta];
  }
  async tags(params) {
    const tenant = params.where.tenant;
    const locale = params.where.locale;
    const model = this.modelWithContext({
      tenant,
      locale
    });
    const uniqueValues = await this.security.withoutAuthorization(() => {
      return this.cms.getUniqueFieldValues(model, {
        fieldId: "tags",
        where: {
          ...this.tagsWhereProcessor.process(params.where),
          latest: true
        }
      });
    });
    return uniqueValues.map(uv => ({
      tag: uv.value,
      count: uv.count
    })).sort((a, b) => {
      return a.tag < b.tag ? -1 : 1;
    }).sort((a, b) => {
      return a.count > b.count ? -1 : 1;
    });
  }
  async update({
    file
  }) {
    const model = this.modelWithContext(file);
    return await this.security.withoutAuthorization(async () => {
      const entry = await this.cms.getEntry(model, {
        where: {
          entryId: file.id,
          latest: true
        }
      });
      const values = (0, _omit.default)(file, ["id", "tenant", "locale", "webinyVersion"]);
      const updatedEntry = await this.cms.updateEntry(model, entry.id, {
        ...values,
        wbyAco_location: values.location ?? entry.location
      });
      await this.aliases.storeAliases(file);
      return this.getFileFieldValues(updatedEntry);
    });
  }
  getFileFieldValues(entry) {
    return {
      id: entry.entryId,
      // We're safe to use entry-level meta fields because we don't use revisions with files.
      createdBy: entry.createdBy,
      modifiedBy: entry.modifiedBy || null,
      savedBy: entry.savedBy,
      createdOn: entry.createdOn,
      modifiedOn: entry.modifiedOn || null,
      savedOn: entry.savedOn,
      locale: entry.locale,
      tenant: entry.tenant,
      webinyVersion: entry.webinyVersion,
      ...entry.values
    };
  }
}
exports.CmsFilesStorage = CmsFilesStorage;

//# sourceMappingURL=CmsFilesStorage.js.map