"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PrivateFilesAssetProcessor = void 0;
var _NotAuthorizedOutputStrategy = require("./NotAuthorizedOutputStrategy");
var _internalIdentity = require("./internalIdentity");
var _RedirectToPublicUrlOutputStrategy = require("./RedirectToPublicUrlOutputStrategy");
var _RedirectToPrivateUrlOutputStrategy = require("./RedirectToPrivateUrlOutputStrategy");
var _PrivateCache = require("./PrivateCache");
var _PublicCache = require("./PublicCache");
class PrivateFilesAssetProcessor {
  constructor(context, assetAuthorizer, assetProcessor) {
    this.assetAuthorizer = assetAuthorizer;
    this.context = context;
    this.assetProcessor = assetProcessor;
  }
  async process(assetRequest, asset) {
    const id = asset.getId();
    const {
      security
    } = this.context;

    // Get file from File Manager by `id`.
    const file = await security.withIdentity(_internalIdentity.internalIdentity, () => {
      return security.withoutAuthorization(() => this.context.fileManager.getFile(id));
    });
    const isPrivateFile = this.isPrivate(file);
    if (!isPrivateFile && this.requestedViaPrivateEndpoint(assetRequest)) {
      asset.setOutputStrategy(new _RedirectToPublicUrlOutputStrategy.RedirectToPublicUrlOutputStrategy(assetRequest));
      return asset;
    }
    if (isPrivateFile && this.requestedViaPublicEndpoint(assetRequest)) {
      asset.setOutputStrategy(new _RedirectToPrivateUrlOutputStrategy.RedirectToPrivateUrlOutputStrategy(assetRequest));
      return asset;
    }
    try {
      await this.assetAuthorizer.authorize(file);
    } catch (error) {
      asset.setOutputStrategy(new _NotAuthorizedOutputStrategy.NotAuthorizedOutputStrategy());
      return asset;
    }
    const processedAsset = await this.assetProcessor.process(assetRequest, asset);
    processedAsset.setOutputStrategy(strategy => {
      return isPrivateFile ? new _PrivateCache.PrivateCache(30, strategy) : new _PublicCache.PublicCache(365, strategy);
    });
    return processedAsset;
  }
  isPrivate(file) {
    return file.accessControl && file.accessControl.type.startsWith("private-");
  }
  requestedViaPrivateEndpoint(assetRequest) {
    return assetRequest.getContext().private;
  }
  requestedViaPublicEndpoint(assetRequest) {
    return !this.requestedViaPrivateEndpoint(assetRequest);
  }
}
exports.PrivateFilesAssetProcessor = PrivateFilesAssetProcessor;

//# sourceMappingURL=PrivateFilesAssetProcessor.js.map