"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.setupAssetDelivery = void 0;
var _handler = require("@webiny/handler");
var _PrivateFilesAssetProcessor = require("./AssetDelivery/privateFiles/PrivateFilesAssetProcessor");
var _PrivateAuthenticatedAuthorizer = require("./AssetDelivery/privateFiles/PrivateAuthenticatedAuthorizer");
var _PrivateFileAssetRequestResolver = require("./AssetDelivery/privateFiles/PrivateFileAssetRequestResolver");
var _index = require("./index");
const noCacheHeaders = _handler.ResponseHeaders.create({
  "content-type": "application/json",
  "cache-control": "no-cache, no-store, must-revalidate"
});
function assertAssetRequestWasResolved(request) {
  if (request === undefined) {
    throw new Error("Not an AssetRequest!");
  }
}
function assertAssetWasResolved(asset) {
  if (asset === undefined) {
    throw new Error("Not an Asset!");
  }
}
const setupAssetDelivery = params => {
  const outputAsset = async (reply, asset) => {
    const assetReply = await asset.output();
    const headers = assetReply.getHeaders();

    // Set default headers.
    headers.set("x-webiny-base64-encoded", true);
    reply.code(assetReply.getCode());
    reply.headers(headers.getHeaders());
    return reply.send(await assetReply.getBody());
  };
  return [(0, _handler.createModifyFastifyPlugin)(app => {
    // Config builder allows config modification via plugins.
    const configBuilder = new _index.AssetDeliveryConfigBuilder();

    // Apply config modifications.
    const configPlugins = app.webiny.plugins.byType(_index.AssetDeliveryConfigModifierPlugin.type);
    configPlugins.forEach(configPlugin => configPlugin.buildConfig(configBuilder));
    let resolvedRequest;
    let resolvedAsset;

    // Create a `HandlerOnRequest` plugin to resolve `tenant` and `locale`, and allow the system to bootstrap.
    const handlerOnRequest = (0, _handler.createHandlerOnRequest)(async (request, reply) => {
      const requestResolver = configBuilder.getAssetRequestResolver();
      resolvedRequest = await requestResolver.resolve(request);
      if (!resolvedRequest) {
        reply.code(404).headers(noCacheHeaders.getHeaders()).send({
          error: "Unable to resolve the request!"
        }).hijack();
        return false;
      }
      const assetResolver = configBuilder.getAssetResolver();
      resolvedAsset = await assetResolver.resolve(resolvedRequest);
      if (!resolvedAsset) {
        reply.code(404).headers(noCacheHeaders.getHeaders()).send({
          error: "Asset not found!"
        }).hijack();
        return false;
      }
      request.headers = {
        ...request.headers,
        "x-tenant": resolvedAsset.getTenant(),
        "x-i18n-locale": resolvedAsset.getLocale()
      };
      return;
    });

    // Create the `Route` plugin, to handle all GET requests, and output the resolved asset.
    const deliveryRoute = (0, _handler.createRoute)(({
      onGet,
      context
    }) => {
      onGet("*", async (_, reply) => {
        assertAssetRequestWasResolved(resolvedRequest);
        assertAssetWasResolved(resolvedAsset);
        if (context.wcp.canUsePrivateFiles()) {
          configBuilder.decorateAssetProcessor(({
            assetProcessor,
            context
          }) => {
            // Currently, we only have one authorizer.
            const assetAuthorizer = new _PrivateAuthenticatedAuthorizer.PrivateAuthenticatedAuthorizer(context);
            return new _PrivateFilesAssetProcessor.PrivateFilesAssetProcessor(context, assetAuthorizer, assetProcessor);
          });
        }
        const outputStrategy = configBuilder.getAssetOutputStrategy(context, resolvedRequest, resolvedAsset);
        resolvedAsset.setOutputStrategy(outputStrategy);
        const assetProcessor = configBuilder.getAssetProcessor(context);
        const processedAsset = await assetProcessor.process(resolvedRequest, resolvedAsset);

        // Get reply object (runs the output strategy under the hood).
        return outputAsset(reply, processedAsset);
      }, {
        override: true
      });
    });
    app.webiny.plugins.register(handlerOnRequest, deliveryRoute);
  }),
  // Create the default configuration
  (0, _index.createAssetDeliveryConfig)(config => {
    config.decorateAssetRequestResolver(() => {
      // This resolver works with `/files/*` requests.
      return new _index.FilesAssetRequestResolver();
    });
    config.decorateAssetRequestResolver(({
      assetRequestResolver
    }) => {
      // This resolver tries to resolve the request using aliases.
      return new _index.AliasAssetRequestResolver(params.documentClient, assetRequestResolver);
    });
    config.decorateAssetRequestResolver(({
      assetRequestResolver
    }) => {
      // This resolver works with `/private/*` requests.
      return new _PrivateFileAssetRequestResolver.PrivateFileAssetRequestResolver(assetRequestResolver);
    });
  })];
};
exports.setupAssetDelivery = setupAssetDelivery;

//# sourceMappingURL=setupAssetDelivery.js.map