"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getFileByUrl = void 0;
var _handlerGraphql = require("@webiny/handler-graphql");
var _apiSecurity = require("@webiny/api-security");
const getFileByUrl = () => {
  const fileManagerGraphQL = new _handlerGraphql.GraphQLSchemaPlugin({
    typeDefs: /* GraphQL */`
            extend type FmQuery {
                getFileByUrl(url: String!): FmFileResponse
            }
        `,
    resolvers: {
      FmQuery: {
        async getFileByUrl(_, args, context) {
          const {
            url
          } = args;
          const useCase = new SecureGetFileByUrl(context.security, new GetFileByUrlUseCase(context.fileManager));
          try {
            const file = await useCase.execute(url);
            if (file) {
              return new _handlerGraphql.Response(file);
            }
            return new _handlerGraphql.NotFoundResponse("File not found!");
          } catch (error) {
            return new _handlerGraphql.ErrorResponse(error);
          }
        }
      }
    }
  });
  fileManagerGraphQL.name = "fm.graphql.getFileByUrl";
  return fileManagerGraphQL;
};
exports.getFileByUrl = getFileByUrl;
class GetFileByUrlUseCase {
  constructor(fileManager) {
    this.fileManager = fileManager;
  }
  async execute(url) {
    const {
      pathname
    } = new URL(url);
    const isAlias = !pathname.startsWith("/files/") && !pathname.startsWith("/private/");
    const query = isAlias ? pathname : pathname.replace("/files/", "").replace("/private/", "");
    const [files] = await this.fileManager.listFiles({
      where: {
        OR: [{
          key: query
        }, {
          aliases_contains: query
        }]
      },
      limit: 1
    });
    return files.length ? files[0] : undefined;
  }
}
class SecureGetFileByUrl {
  constructor(security, useCase) {
    this.security = security;
    this.useCase = useCase;
  }
  execute(url) {
    if (!this.security.getIdentity()) {
      throw new _apiSecurity.NotAuthorizedError({
        message: "You're not authorized to edit this file!"
      });
    }
    return this.useCase.execute(url);
  }
}

//# sourceMappingURL=getFileByUrl.js.map